# opinel

[![Build Status](https://travis-ci.org/iSECPartners/opinel.svg?branch=master)](https://travis-ci.org/iSECPartners/opinel)

opinel is a Python package used by [Scout2](https://github.com/iSECPartners/Scout2) and the [AWS-Recipes](https://github.com/iSECPartners/AWS-Recipes).

## Installation

### From Source

    $ git clone https://github.com/iSECPartners/opinel
    $ cd opinel
    $ python setup.py install

### From PIP

    $ pip install opinel
